@@ -3,9 +3,9 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
-use Time::Moment;
+use Time::Moment 0.38;
 use DateTimeX::Moment::Duration;
 use DateTime::Locale;
 use DateTime::TimeZone;
